@@ -73,6 +73,7 @@ new S3ToLambda(scope: Construct, id: string, props: S3ToLambdaProps);
 |:-------------|:----------------|-----------------|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of the lambda.Function created by the construct|
 |s3Bucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the s3.Bucket created by the construct|
+|s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket.|
 
 ## Default settings
 
@@ -172,6 +173,11 @@ class S3ToLambda(
     def s3_bucket(self) -> aws_cdk.aws_s3.Bucket:
         return jsii.get(self, "s3Bucket")
 
+    @builtins.property
+    @jsii.member(jsii_name="s3LoggingBucket")
+    def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        return jsii.get(self, "s3LoggingBucket")
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-s3-lambda.S3ToLambdaProps",
